 // aboutScreen.js

import { StatusBar } from 'expo-status-bar';
import React from 'react';
import { StyleSheet, Text, View, ScrollView, Image } from 'react-native';
import {colors, appLogo, fontStyles, pageTitle, page, appLogoContainer} from './styles/themes'

export default class AboutScreen extends React.Component {
    
    render(){
        return (
            <View>
                <View style={appLogoContainer}>
                    <Image 
                        source={require('./images/SensibleLogo.png')}
                        style={appLogo}/>
                </View>
                <StatusBar hidden />
                <ScrollView style={page}>
                    <View>
                        <Text style={pageTitle}>
                            About
                        </Text>
                    </View> 
                    
                    <View style={styles.info}>
                        <Text style={styles.view}>
                            A joint project of the Ignatian Center for Jesuit Education at Santa Clara University 
                            and Santa Clara University School of Engineering’s Frugal Innovation Hub, Sensible is 
                            an Ignatian spirituality app dedicated entirely to the ongoing production and dissemination 
                            of guided Ignatian contemplations and meditations (exercises). It is designed to be available 
                            whenever you need, especially when you are feeling distracted during your prayer.
                            {"\n"}{"\n"}
                            In the 18th Annotation of the Spiritual Exercises, St. Ignatius writes, “The Spiritual Exercises 
                            must be adapted to the condition of the one who is to engage in them, that is, to [his/her/their] 
                            age, education, and talent (SE, 18).
                            {"\n"}{"\n"}
                            Sensible seeks to do just that: adapt the Spiritual exercises to the condition of those of us who 
                            earnestly seek to do them. And what is that condition? The need and desire for guided meditation 
                            and contemplation is higher now that it ever has been. So many of us are yearning for chances to pause, 
                            close our eyes, and enter into an experience of prayer that nourishes and sustains us so that we can 
                            more freely respond with love to the needs of our world. Yet, today’s world, particularly today’s digital 
                            world, seems to create new distractions almost every second, many of which are on the device sitting 
                            right in front of us twenty-four hours a day. It is increasingly difficult not to become distracted 
                            during meditation or contemplation.
                            {"\n"}{"\n"}
                            Sensible aims to create exercises that penetrate right into one of the most common places of distraction: 
                            our phones. The idea is simple:
                        </Text>
                        <Text style={styles.listItem}>{"\n"}1. Find an exercise that is of interest to you. Each exercise is categorized by theme, by scripture, and by the “week” of the Spiritual Exercises into which it might typically reside.</Text>
                        <Text style={styles.listItem}>2. Find a place with limited distractions and find a position to pray that works for your body.</Text>
                        <Text style={styles.listItem}>3. Connect your phone to headphones or a speaker if you desire better sound quality.</Text>
                        <Text style={styles.listItem}>4. Hit play and do the exercise as it guides you.</Text>
                        <Text style={styles.listItem}>5. Spend some time reflecting or journaling after your experience.</Text>
                        <Text style={styles.view}>
                            The content of the exercises is being produced by the Jesuits and their colleagues of Santa 
                            Clara University.
                        </Text>
                    </View>
                    <Image 
                        source = {require('./images/IgnatianCenterLogo.jpg')} 
                        style={styles.ignatianLogo}
                    />
                </ScrollView>
            </View>
        )
    }
}

const styles = StyleSheet.create({
    info: {
        paddingTop: '2%'
    },
    listItem: {
        textAlign: "left",
        marginLeft: '7%',
        marginRight: '7%',
        marginBottom: '3%',
        fontStyle: "italic",
        fontSize: fontStyles.regularText,
        color: 'black'
    },
    view: {
        fontSize: fontStyles.regularText,
        paddingRight: '5%',
        paddingLeft: '5%',
        color: 'black'
    },
    ignatianLogo: {
        marginTop: '5%',
        alignSelf: "center",
        height: 60,
        width: '75%',
        marginBottom: "35%",
    }
})

